@@ -124,7 +124,7 @@ func Main() int {
 
 	cancel()
 	if err := wg.Wait(); err != nil {
-		glog.V(4).Info("Unhandled error received. Exiting...err: %s", err)
+		glog.V(4).Infof("Unhandled error received. Exiting...err: %v", err)
 		return 1
 	}
 
